@@ -1,10 +1,17 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
-import { AcmAlert, AcmForm, AcmFormProvider, AcmModal, AcmSelect, AcmSubmit } from '@stolostron/ui-components'
+import {
+    AcmAlert,
+    AcmForm,
+    AcmFormProvider,
+    AcmModal,
+    AcmSelect,
+    AcmSubmit,
+} from '@open-cluster-management/ui-components'
 import { ActionGroup, Button, ButtonVariant, ModalVariant, SelectOption } from '@patternfly/react-core'
 import { Fragment, useEffect, useState } from 'react'
 import { useTranslation } from 'react-i18next'
-import { IRequestResult } from '../lib/resource-request'
+import { IRequestResult } from '../resources'
 
 export interface IDropdownActionModalProps<T = undefined> {
     open: true
