@@ -1,6 +1,7 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
-import { AcmAlertInfo } from '@stolostron/ui-components'
+import { ResourceError, ResourceErrorCode } from '../resources'
+import { AcmAlertInfo } from '@open-cluster-management/ui-components'
 import {
     Card,
     CardBody,
@@ -11,7 +12,6 @@ import {
     Title,
 } from '@patternfly/react-core'
 import { ReactNode } from 'react'
-import { ResourceError, ResourceErrorCode } from '../lib/resource-request'
 
 export function getErrorInfo(error: unknown): AcmAlertInfo {
     let title = 'Error'
