@@ -2,13 +2,14 @@
 /* istanbul ignore file */
 
 import '@patternfly/react-core/dist/styles/base.css'
-import { AcmHeader, AcmRoute } from '@stolostron/ui-components'
+import { AcmHeader, AcmRoute } from '@open-cluster-management/ui-components'
 import { PageSection } from '@patternfly/react-core'
 import { StrictMode, Suspense } from 'react'
 import ReactDOM from 'react-dom'
 import App from './App'
 import { RecoilRoot } from 'recoil'
 import { MemoryRouter } from 'react-router'
+import 'regenerator-runtime/runtime'
 
 ReactDOM.render(
     <StrictMode>
