@@ -1,5 +1,14 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
+import { makeStyles } from '@material-ui/styles'
+import {
+    ClusterCurator,
+    deleteResource,
+    filterForTemplatedCurators,
+    getTemplateJobsNum,
+    LinkAnsibleCredential,
+    unpackProviderConnection,
+} from '../../../resources'
 import {
     AcmAlertContext,
     AcmButton,
@@ -9,10 +18,10 @@ import {
     AcmPageHeader,
     AcmRoute,
     AcmTable,
-} from '@stolostron/ui-components'
+} from '@open-cluster-management/ui-components'
+import { ButtonVariant, Hint, PageSection } from '@patternfly/react-core'
 import { ExternalLinkAltIcon } from '@patternfly/react-icons'
 import { fitContent } from '@patternfly/react-table'
-import { PageSection, Hint, ButtonVariant } from '@patternfly/react-core'
 import { Fragment, useContext, useEffect, useMemo, useState } from 'react'
 import { Trans, useTranslation } from 'react-i18next'
 import { Link, useHistory } from 'react-router-dom'
@@ -20,19 +29,9 @@ import { useRecoilState } from 'recoil'
 import { acmRouteState, clusterCuratorsState, configMapsState, secretsState } from '../../../atoms'
 import { BulkActionModel, IBulkActionModelProps } from '../../../components/BulkActionModel'
 import { DropdownActionModal, IDropdownActionModalProps } from '../../../components/DropdownActionModal'
-import { deleteResource } from '../../../lib/resource-request'
-import { NavigationPath } from '../../../NavigationPath'
 import { RbacDropdown } from '../../../components/Rbac'
-
-import {
-    ClusterCurator,
-    filterForTemplatedCurators,
-    getTemplateJobsNum,
-    LinkAnsibleCredential,
-} from '../../../resources/cluster-curator'
-import { unpackProviderConnection } from '../../../resources/provider-connection'
 import { rbacDelete, rbacPatch } from '../../../lib/rbac-util'
-import { makeStyles } from '@material-ui/styles'
+import { NavigationPath } from '../../../NavigationPath'
 
 export default function AnsibleAutomationsPage() {
     const [, setRoute] = useRecoilState(acmRouteState)
@@ -40,7 +39,6 @@ export default function AnsibleAutomationsPage() {
     useEffect(() => setRoute(AcmRoute.Automation), [setRoute])
 
     const alertContext = useContext(AcmAlertContext)
-    // eslint-disable-next-line react-hooks/exhaustive-deps
     useEffect(() => alertContext.clearAlerts, [])
     const { t } = useTranslation(['cluster', 'common'])
 
@@ -278,16 +276,17 @@ function AnsibleJobTemplateTable() {
                 keyFn={(clusterCurator: ClusterCurator) => {
                     return clusterCurator.metadata.uid as string
                 }}
-                tableActions={[
+                tableActionButtons={[
                     {
                         id: 'add',
                         title: t('template.create'),
                         click: () => {
                             history.push(NavigationPath.addAnsibleAutomation)
                         },
+                        variant: ButtonVariant.primary,
                     },
                 ]}
-                bulkActions={[
+                tableActions={[
                     {
                         id: 'deleteTemplate',
                         title: t('bulk.delete.templates'),
@@ -318,6 +317,7 @@ function AnsibleJobTemplateTable() {
                                 icon: 'warning',
                             })
                         },
+                        variant: 'bulk-action',
                     },
                 ]}
                 emptyState={
