@@ -1,22 +1,25 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
-import { Provider } from '@stolostron/ui-components/lib/AcmProvider'
+import {
+    ClusterCurator,
+    ClusterCuratorApiVersion,
+    ClusterCuratorKind,
+    Namespace,
+    NamespaceApiVersion,
+    NamespaceKind,
+    Secret,
+    SecretApiVersion,
+    SecretKind,
+} from '../../../resources'
+import { Provider } from '@open-cluster-management/ui-components/lib/AcmProvider'
 import { render } from '@testing-library/react'
 import { MemoryRouter, Route } from 'react-router-dom'
 import { RecoilRoot } from 'recoil'
 import { clusterCuratorsState, namespacesState, secretsState } from '../../../atoms'
-import { nockCreate, nockIgnoreRBAC } from '../../../lib/nock-util'
-import {
-    clickByPlaceholderText,
-    clickByText,
-    typeByPlaceholderText,
-    typeByTestId,
-    waitForNock,
-} from '../../../lib/test-util'
+import { nockAnsibleTower, nockCreate, nockIgnoreRBAC } from '../../../lib/nock-util'
+import { clickByPlaceholderText, clickByText, typeByPlaceholderText, waitForNock } from '../../../lib/test-util'
 import { NavigationPath } from '../../../NavigationPath'
-import { ClusterCurator, ClusterCuratorApiVersion, ClusterCuratorKind } from '../../../resources/cluster-curator'
-import { Namespace, NamespaceApiVersion, NamespaceKind } from '../../../resources/namespace'
-import { Secret, SecretApiVersion, SecretKind } from '../../../resources/secret'
+import { AnsibleTowerJobTemplateList } from '../../../resources'
 import AnsibleAutomationsFormPage from './AnsibleAutomationsForm'
 
 const mockNamespaces: Namespace[] = [
@@ -38,6 +41,10 @@ const mockSecret: Secret = {
             'cluster.open-cluster-management.io/credentials': '',
         },
     },
+    stringData: {
+        host: 'https://ansible-tower-web-svc-tower.com',
+        token: 'abcd',
+    },
 }
 
 function AddAnsibleTemplateTest() {
@@ -87,13 +94,38 @@ const mockClusterCurator: ClusterCurator = {
     },
 }
 
+const mockAnsibleCredential = {
+    towerHost: 'https://ansible-tower-web-svc-tower.com/api/v2/job_templates/',
+    token: 'abcd',
+}
+
+const mockTemplateList: AnsibleTowerJobTemplateList = {
+    results: [
+        {
+            name: 'test-job-pre-install',
+        },
+        {
+            name: 'test-job-post-install',
+        },
+        {
+            name: 'test-job-pre-upgrade',
+        },
+        {
+            name: 'test-job-post-upgrade',
+        },
+    ],
+}
+
 describe('add ansible job template page', () => {
-    beforeEach(() => nockIgnoreRBAC())
+    beforeEach(() => {
+        nockIgnoreRBAC()
+    })
 
     it('should create a curator template', async () => {
         render(<AddAnsibleTemplateTest />)
 
         // template information
+        nockAnsibleTower(mockAnsibleCredential, mockTemplateList)
         await typeByPlaceholderText('template.create.placeholder', mockClusterCurator.metadata.name!)
         await clickByPlaceholderText('credentials:credentialsForm.ansibleCredentials.placeholder')
         await clickByText(mockSecret.metadata.name!)
@@ -101,42 +133,29 @@ describe('add ansible job template page', () => {
 
         // install templates
         await clickByText('template.job.placeholder', 0)
-        await typeByTestId('job-name', mockClusterCurator.spec!.install!.prehook![0].name)
+        await clickByPlaceholderText('cluster:template.modal.name.placeholder', 0)
+        await clickByText(mockTemplateList.results![0].name!, 0)
         await clickByText('common:save')
         await clickByText('template.job.placeholder', 1)
-        await typeByTestId('job-name', mockClusterCurator.spec!.install!.posthook![0].name)
+        await clickByPlaceholderText('cluster:template.modal.name.placeholder', 0)
+        await clickByText(mockTemplateList.results![1].name!, 0)
         await clickByText('common:save')
         await clickByText('common:next')
 
         // upgrade templates
         await clickByText('template.job.placeholder', 0)
-        await typeByTestId('job-name', mockClusterCurator.spec!.upgrade!.prehook![0].name)
+        await clickByPlaceholderText('cluster:template.modal.name.placeholder', 0)
+        await clickByText(mockTemplateList.results![2].name!, 0)
         await clickByText('common:save')
         await clickByText('template.job.placeholder', 1)
-        await typeByTestId('job-name', mockClusterCurator.spec!.upgrade!.posthook![0].name)
+        await clickByPlaceholderText('cluster:template.modal.name.placeholder', 0)
+        await clickByText(mockTemplateList.results![3].name!, 0)
         await clickByText('common:save')
         await clickByText('common:next')
 
-        // scale templates
-        // await clickByText('template.job.placeholder', 0)
-        // await typeByTestId('job-name', mockClusterCurator.spec!.scale!.prehook![0].name)
-        // await clickByText('common:save')
-        // await clickByText('template.job.placeholder', 1)
-        // await typeByTestId('job-name', mockClusterCurator.spec!.scale!.posthook![0].name)
-        // await clickByText('common:save')
-        // await clickByText('common:next')
-
-        // destroy templates
-        // await clickByText('template.job.placeholder', 0)
-        // await typeByTestId('job-name', mockClusterCurator.spec!.destroy!.prehook![0].name)
-        // await clickByText('common:save')
-        // await clickByText('template.job.placeholder', 1)
-        // await typeByTestId('job-name', mockClusterCurator.spec!.destroy!.posthook![0].name)
-        // await clickByText('common:save')
-        // await clickByText('common:next')
-
         // add template
         const createNock = nockCreate(mockClusterCurator)
+        nockAnsibleTower(mockAnsibleCredential, mockTemplateList)
         await clickByText('common:add')
         await waitForNock(createNock)
     })
