@@ -1,5 +1,16 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
+import {
+    BareMetalAsset,
+    BareMetalAssetConditionReasons,
+    BareMetalAssetConditionTypes,
+    createBareMetalAssetNamespaces,
+    deleteResource,
+    importBareMetalAsset,
+    ImportedBareMetalAsset,
+    IRequestResult,
+    ManagedClusterDefinition,
+} from '../../../resources'
 import {
     AcmButton,
     AcmEmptyState,
@@ -8,8 +19,8 @@ import {
     AcmPageHeader,
     AcmRoute,
     AcmTable,
-} from '@stolostron/ui-components'
-import { ActionList, ActionListItem, Bullseye, PageSection, ButtonVariant } from '@patternfly/react-core'
+} from '@open-cluster-management/ui-components'
+import { ActionList, ActionListItem, Bullseye, ButtonVariant, PageSection } from '@patternfly/react-core'
 import { fitContent } from '@patternfly/react-table'
 import { Fragment, useEffect, useState } from 'react'
 import { Trans, useTranslation } from 'react-i18next'
@@ -22,17 +33,7 @@ import { importBMAs } from '../../../lib/bare-metal-assets'
 import { deleteResources } from '../../../lib/delete-resources'
 import { DOC_LINKS } from '../../../lib/doc-util'
 import { canUser, rbacDelete, rbacPatch } from '../../../lib/rbac-util'
-import { deleteResource, IRequestResult } from '../../../lib/resource-request'
 import { NavigationPath } from '../../../NavigationPath'
-import {
-    BareMetalAsset,
-    BareMetalAssetConditionReasons,
-    BareMetalAssetConditionTypes,
-    createBareMetalAssetNamespaces,
-    importBareMetalAsset,
-    ImportedBareMetalAsset,
-} from '../../../resources/bare-metal-asset'
-import { ManagedClusterDefinition } from '../../../resources/managed-cluster'
 
 export default function BareMetalAssetsPage() {
     const [, setRoute] = useRecoilState(acmRouteState)
@@ -374,20 +375,21 @@ export function BareMetalAssetsTable(props: {
                     },
                 ]}
                 keyFn={keyFn}
-                tableActions={[
+                tableActionButtons={[
                     {
                         id: 'createAsset',
                         title: t('bareMetalAsset.bulkAction.createAsset'),
                         click: () => history.push(NavigationPath.createBareMetalAsset),
+                        variant: ButtonVariant.primary,
                     },
                     {
                         id: 'importAsset',
                         title: t('bareMetalAsset.bulkAction.importAssets'),
-                        variant: ButtonVariant.secondary,
                         click: () => setImportModalProps(),
+                        variant: ButtonVariant.secondary,
                     },
                 ]}
-                bulkActions={[
+                tableActions={[
                     {
                         id: 'deleteBareMetalAsset',
                         title: t('bareMetalAsset.bulkAction.deleteAsset'),
@@ -420,6 +422,7 @@ export function BareMetalAssetsTable(props: {
                                 icon: 'warning',
                             })
                         },
+                        variant: 'bulk-action',
                     },
                     {
                         id: 'createBareMetalAssetCluster',
@@ -432,6 +435,7 @@ export function BareMetalAssetsTable(props: {
                         },
                         isDisabled: !canCreateCluster,
                         tooltip: !canCreateCluster ? t('common:rbac.unauthorized') : '',
+                        variant: 'bulk-action',
                     },
                 ]}
                 rowActions={[]}
