@@ -1,19 +1,18 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
-import { useState, useEffect } from 'react'
-import { useTranslation, Trans } from 'react-i18next'
+import { ClusterPool, patchResource } from '../../../../../resources'
 import {
-    AcmForm,
-    AcmSubmit,
-    AcmButton,
-    AcmModal,
-    AcmAlertGroup,
     AcmAlertContext,
+    AcmAlertGroup,
+    AcmButton,
+    AcmForm,
+    AcmModal,
     AcmNumberInput,
-} from '@stolostron/ui-components'
-import { ModalVariant, ActionGroup } from '@patternfly/react-core'
-import { ClusterPool } from '../../../../../resources/cluster-pool'
-import { patchResource } from '../../../../../lib/resource-request'
+    AcmSubmit,
+} from '@open-cluster-management/ui-components'
+import { ActionGroup, ModalVariant } from '@patternfly/react-core'
+import { useEffect, useState } from 'react'
+import { Trans, useTranslation } from 'react-i18next'
 
 export type ScaleClusterPoolModalProps = {
     clusterPool?: ClusterPool
