@@ -1,13 +1,15 @@
 /* Copyright Contributors to the Open Cluster Management project */
-import { DiscoveredCluster } from '../../../../../resources/discovered-cluster'
-import { Secret, SecretApiVersion, SecretKind } from '../../../../../resources/secret'
-import { Provider } from '@stolostron/ui-components'
-import { SelfSubjectAccessReview } from '../../../../../resources/self-subject-access-review'
 import {
+    DiscoveredCluster,
     DiscoveryConfig,
     DiscoveryConfigApiVersion,
     DiscoveryConfigKind,
-} from '../../../../../resources/discovery-config'
+    Secret,
+    SecretApiVersion,
+    SecretKind,
+    SelfSubjectAccessReview,
+} from '../../../../../resources'
+import { Provider } from '@open-cluster-management/ui-components'
 
 export const mockDiscoveredClusters: DiscoveredCluster[] = [
     {
