@@ -1,7 +1,17 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
 import {
-    AcmToastContext,
+    createDiscoveryConfig,
+    deleteResource,
+    DiscoveryConfig,
+    DiscoveryConfigApiVersion,
+    DiscoveryConfigDefinition,
+    DiscoveryConfigKind,
+    replaceDiscoveryConfig,
+    ResourceError,
+    Secret,
+} from '../../../../../resources'
+import {
     AcmAlertContext,
     AcmButton,
     AcmForm,
@@ -14,8 +24,9 @@ import {
     AcmPageHeader,
     AcmSelect,
     AcmSubmit,
+    AcmToastContext,
     Provider,
-} from '@stolostron/ui-components'
+} from '@open-cluster-management/ui-components'
 import {
     ActionGroup,
     ButtonVariant,
@@ -27,27 +38,17 @@ import {
     Text,
     TextVariants,
 } from '@patternfly/react-core'
-import { useContext, useEffect, useState, Fragment } from 'react'
+import { Fragment, useContext, useEffect, useState } from 'react'
 import { Trans, useTranslation } from 'react-i18next'
 import { Link, useHistory, useLocation } from 'react-router-dom'
 import { useRecoilState } from 'recoil'
 import { discoveryConfigState, secretsState } from '../../../../../atoms'
 import { ConfirmModal, IConfirmModalProps } from '../../../../../components/ConfirmModal'
-import discoveryVersions from '../../../../../components/discoveryVersions.json'
 import { getErrorInfo } from '../../../../../components/ErrorPage'
-import { deleteResource } from '../../../../../lib/resource-request'
-import { NavigationPath } from '../../../../../NavigationPath'
-import { Secret } from '../../../../../resources/secret'
 import { canUser } from '../../../../../lib/rbac-util'
-import {
-    createDiscoveryConfig,
-    DiscoveryConfig,
-    DiscoveryConfigApiVersion,
-    DiscoveryConfigKind,
-    replaceDiscoveryConfig,
-    DiscoveryConfigDefinition,
-} from '../../../../../resources/discovery-config'
-import { ResourceError } from '../../../../../lib/resource-request'
+import { NavigationPath } from '../../../../../NavigationPath'
+
+const discoveryVersions = ['4.6', '4.7', '4.8', '4.9']
 
 export default function DiscoveryConfigPage() {
     const { t } = useTranslation(['discovery'])
@@ -337,7 +338,6 @@ export function DiscoveryConfigPageContent(props: {
                 canCreateDiscoveryConfig.abort()
             }
         }
-        // eslint-disable-next-line react-hooks/exhaustive-deps
     }, [editing, discoveryConfig.metadata.namespace])
 
     return (
