@@ -1,10 +1,10 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
-import { AcmInlineStatus, AcmPageContent, AcmTable, StatusType } from '@stolostron/ui-components'
+import { Addon, AddonStatus } from '../../../../../../resources'
+import { AcmInlineStatus, AcmPageContent, AcmTable, StatusType } from '@open-cluster-management/ui-components'
 import { PageSection } from '@patternfly/react-core'
 import { useContext } from 'react'
 import { useTranslation } from 'react-i18next'
-import { Addon, AddonStatus } from '../../../../../../lib/get-addons'
 import { ClusterContext } from '../ClusterDetails'
 
 export function ClustersSettingsPageContent() {
@@ -63,7 +63,6 @@ export function ClusterSettingsTable(props: { addons: Addon[] | undefined }) {
             ]}
             keyFn={(addon: Addon) => addon.name}
             tableActions={[]}
-            bulkActions={[]}
             rowActions={[]}
         />
     )
