@@ -1,20 +1,22 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
-import { AcmSelect } from '@stolostron/ui-components'
-import { SelectOption, TextContent, Text, TextVariants } from '@patternfly/react-core'
+import {
+    Cluster,
+    ClusterCurator,
+    ClusterCuratorDefinition,
+    ClusterStatus,
+    createResource,
+    IRequestResult,
+    patchResource,
+    ResourceError,
+    ResourceErrorCode,
+} from '../../../../../resources'
+import { AcmSelect } from '@open-cluster-management/ui-components'
+import { SelectOption, Text, TextContent, TextVariants } from '@patternfly/react-core'
 import { useEffect, useState } from 'react'
 import { useTranslation } from 'react-i18next'
 import { BulkActionModel } from '../../../../../components/BulkActionModel'
 import { ReleaseNotesLink } from './ReleaseNotesLink'
-import { Cluster, ClusterStatus } from '../../../../../lib/get-cluster'
-import {
-    IRequestResult,
-    patchResource,
-    createResource,
-    ResourceError,
-    ResourceErrorCode,
-} from '../../../../../lib/resource-request'
-import { ClusterCurator, ClusterCuratorDefinition } from '../../../../../resources/cluster-curator'
 import './style.css'
 export const backendUrl = `${process.env.REACT_APP_BACKEND_PATH}`
 
@@ -107,7 +109,7 @@ export function BatchUpgradeModal(props: {
                 {
                     header: t('upgrade.table.currentversion'),
                     cell: (item: Cluster) => {
-                        const currentVersion = item?.distribution?.upgradeInfo.currentVersion || ''
+                        const currentVersion = item?.distribution?.upgradeInfo?.currentVersion || ''
                         return <span>{currentVersion}</span>
                     },
                 },
