@@ -1,19 +1,15 @@
 /* Copyright Contributors to the Open Cluster Management project */
 
 import { makeStyles } from '@material-ui/styles'
-import { AcmAlert, AcmButton } from '@stolostron/ui-components'
+import { Cluster, ClusterProvision, ClusterStatus, ConfigMap, getHivePod, getLatest } from '../../../../../resources'
+import { AcmAlert, AcmButton } from '@open-cluster-management/ui-components'
 import { AlertVariant, ButtonVariant } from '@patternfly/react-core'
 import { ExternalLinkAltIcon } from '@patternfly/react-icons'
 import { Fragment, useContext } from 'react'
 import { useTranslation } from 'react-i18next'
-import { Cluster, ClusterStatus } from '../../../../../lib/get-cluster'
-import { getLatest } from '../../../../../lib/utils'
-import { ClusterProvision } from '../../../../../resources/cluster-provision'
-import { getHivePod } from '../../../../../resources/pod'
-import { ClusterContext } from '../ClusterDetails/ClusterDetails'
-import { configMapsState, clusterProvisionsState } from '../../../../../atoms'
-import { ConfigMap } from '../../../../../resources/configmap'
 import { useRecoilState } from 'recoil'
+import { clusterProvisionsState, configMapsState } from '../../../../../atoms'
+import { ClusterContext } from '../ClusterDetails/ClusterDetails'
 
 const useStyles = makeStyles({
     logsButton: {
