@@ -1235,11 +1235,7 @@ module.exports = {
 		"12.0.17",
 		"12.0.18",
 		"12.1.0",
-		"12.1.1",
-		"12.1.2",
-		"12.2.0",
-		"12.2.1",
-		"12.2.2"
+		"12.1.1"
 	],
 	"90.0.4402.0": [
 		"13.0.0-beta.2",
@@ -1367,12 +1363,7 @@ module.exports = {
 		"13.2.2",
 		"13.2.3",
 		"13.3.0",
-		"13.4.0",
-		"13.5.0",
-		"13.5.1",
-		"13.5.2",
-		"13.6.0",
-		"13.6.1"
+		"13.4.0"
 	],
 	"92.0.4511.0": [
 		"14.0.0-beta.1",
@@ -1482,12 +1473,6 @@ module.exports = {
 	"93.0.4577.63": [
 		"14.0.1"
 	],
-	"93.0.4577.82": [
-		"14.0.2",
-		"14.1.0",
-		"14.1.1",
-		"14.2.0"
-	],
 	"94.0.4584.0": [
 		"15.0.0-alpha.3",
 		"15.0.0-alpha.4",
@@ -1555,28 +1540,16 @@ module.exports = {
 		"15.0.0-nightly.20210702",
 		"15.0.0-nightly.20210705"
 	],
-	"94.0.4606.51": [
-		"15.0.0"
-	],
-	"94.0.4606.61": [
-		"15.1.0",
-		"15.1.1"
-	],
-	"94.0.4606.71": [
-		"15.1.2"
-	],
-	"94.0.4606.81": [
-		"15.2.0",
-		"15.3.0"
+	"95.0.4612.5": [
+		"16.0.0-nightly.20210824",
+		"16.0.0-nightly.20210825",
+		"16.0.0-nightly.20210826",
+		"16.0.0-nightly.20210827",
+		"16.0.0-nightly.20210830",
+		"16.0.0-nightly.20210831",
+		"16.0.0-nightly.20210901"
 	],
 	"95.0.4629.0": [
-		"16.0.0-alpha.1",
-		"16.0.0-alpha.2",
-		"16.0.0-alpha.3",
-		"16.0.0-alpha.4",
-		"16.0.0-alpha.5",
-		"16.0.0-alpha.6",
-		"16.0.0-alpha.7",
 		"16.0.0-nightly.20210902",
 		"16.0.0-nightly.20210903",
 		"16.0.0-nightly.20210906",
@@ -1588,57 +1561,6 @@ module.exports = {
 		"16.0.0-nightly.20210914",
 		"16.0.0-nightly.20210915",
 		"16.0.0-nightly.20210916",
-		"16.0.0-nightly.20210917",
-		"16.0.0-nightly.20210920",
-		"16.0.0-nightly.20210921",
-		"16.0.0-nightly.20210922",
-		"17.0.0-nightly.20210923",
-		"17.0.0-nightly.20210924",
-		"17.0.0-nightly.20210927",
-		"17.0.0-nightly.20210928",
-		"17.0.0-nightly.20210929",
-		"17.0.0-nightly.20210930",
-		"17.0.0-nightly.20211001",
-		"17.0.0-nightly.20211004",
-		"17.0.0-nightly.20211005"
-	],
-	"96.0.4647.0": [
-		"16.0.0-alpha.8",
-		"16.0.0-alpha.9",
-		"16.0.0-beta.1",
-		"16.0.0-beta.2",
-		"16.0.0-beta.3",
-		"17.0.0-nightly.20211006",
-		"17.0.0-nightly.20211007",
-		"17.0.0-nightly.20211008",
-		"17.0.0-nightly.20211011",
-		"17.0.0-nightly.20211012",
-		"17.0.0-nightly.20211013",
-		"17.0.0-nightly.20211014",
-		"17.0.0-nightly.20211015",
-		"17.0.0-nightly.20211018",
-		"17.0.0-nightly.20211019",
-		"17.0.0-nightly.20211020",
-		"17.0.0-nightly.20211021"
-	],
-	"96.0.4664.18": [
-		"16.0.0-beta.4",
-		"16.0.0-beta.5"
-	],
-	"95.0.4612.5": [
-		"16.0.0-nightly.20210824",
-		"16.0.0-nightly.20210825",
-		"16.0.0-nightly.20210826",
-		"16.0.0-nightly.20210827",
-		"16.0.0-nightly.20210830",
-		"16.0.0-nightly.20210831",
-		"16.0.0-nightly.20210901"
-	],
-	"96.0.4664.4": [
-		"17.0.0-nightly.20211022",
-		"17.0.0-nightly.20211025",
-		"17.0.0-nightly.20211026",
-		"17.0.0-nightly.20211027",
-		"17.0.0-nightly.20211028"
+		"16.0.0-nightly.20210917"
 	]
 };
\ No newline at end of file
