@@ -6,17 +6,11 @@
 'use strict';
 
 const docsUrl = require('../util/docsUrl');
-const report = require('../util/report');
 
 // ------------------------------------------------------------------------------
 // Rule Definition
 // ------------------------------------------------------------------------------
 
-const messages = {
-  badHandlerName: 'Handler function for {{propKey}} prop key must be a camelCase name beginning with \'{{handlerPrefix}}\' only',
-  badPropKey: 'Prop key for {{propValue}} must begin with \'{{handlerPropPrefix}}\''
-};
-
 module.exports = {
   meta: {
     docs: {
@@ -26,7 +20,10 @@ module.exports = {
       url: docsUrl('jsx-handler-names')
     },
 
-    messages,
+    messages: {
+      badHandlerName: 'Handler function for {{propKey}} prop key must be a camelCase name beginning with \'{{handlerPrefix}}\' only',
+      badPropKey: 'Prop key for {{propValue}} must begin with \'{{handlerPropPrefix}}\''
+    },
 
     schema: [{
       anyOf: [
@@ -145,8 +142,9 @@ module.exports = {
           && propFnIsNamedCorrectly !== null
           && !propFnIsNamedCorrectly
         ) {
-          report(context, messages.badHandlerName, 'badHandlerName', {
+          context.report({
             node,
+            messageId: 'badHandlerName',
             data: {
               propKey,
               handlerPrefix: eventHandlerPrefix
@@ -157,8 +155,9 @@ module.exports = {
           && propIsEventHandler !== null
           && !propIsEventHandler
         ) {
-          report(context, messages.badPropKey, 'badPropKey', {
+          context.report({
             node,
+            messageId: 'badPropKey',
             data: {
               propValue,
               handlerPropPrefix: eventHandlerPropPrefix
